# 🏛️ Original Bible Stuite

`Original Reader’s Bible (ORB)`: The standard text of the original Hebrew & Greek, with instant pop-up parsing and dictionary (lemma) forms for every word.

`Original Interlinear Bible (OIB)`: The original Hebrew & Greek text with a word-for-word, in-line English translation directly beneath each word.

`Original Parallel Bible (OPB)`: The original Hebrew & Greek text displayed side-by-side with a flowing English translation, aligned by verse.

`Original Discourse Bible (ODB)`: The original Hebrew & Greek text dynamically structured by clause, designed to reveal argument flow and narrative structure.

`Original Linguistic Bible (OLB)`: The original Hebrew & Greek text featuring expert linguistic notes on key grammatical, syntactical, and lexical details.